EmbeddingChannel class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invoke<
T> (String method, {Map< String, dynamic> data = const {}, bool withPerformanceTracing = false}) → Future<T?> -
nativeMethodCallHandler(
MethodCall methodCall) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
String method, Handler handler) → VoidCallback -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → EmbeddingChannel
-
final