EmbeddingController class

Constructors

EmbeddingController(List<String> args)

Properties

embeddingChannel ↔ EmbeddingChannel
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startConfig ↔ Completer<Map<String, dynamic>>
getter/setter pair

Methods

addEmbeddingHandoverService(Service service) → void
addHandoverHandler(String method, Handler handler) → void
Add a handler for a handover event.
exit() → void
handoverChannel() → EmbeddingMethodClientChannel
invokeHandover(String method, {Map<String, dynamic> arguments = const {}}) → Future<String?>
Invoke a handover event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → EmbeddingController