MyClientCall<Q, R> class

Constructors

MyClientCall(ClientMethod<Q, R> method, Stream<Q> requests, CallOptions options)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Future<Map<String, String>>
Header metadata returned from the server.
no setterinherited
isCancelled ↔ bool
getter/setter pairinherited
options → CallOptions
finalinherited
response → Stream<R>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailers → Future<Map<String, String>>
Trailer metadata returned from the server.
no setterinherited

Methods

cancel() → Future<void>
Cancel this gRPC call. Any remaining request objects will not be sent, and no further responses will be received.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnectionError(Object error) → void
inherited
onConnectionReady(ClientConnection connection) → void
inherited
setResponse(R data) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited